@@ -10,7 +10,6 @@ import os.path as osp
 from typing import TYPE_CHECKING, Any
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
@@ -82,6 +81,7 @@ class BaseImageItem(QwtPlotItem):
     _can_rotate = False
     _readonly = False
     _private = False
+    _icon_name = "image.png"
 
     def __init__(
         self, data: np.ndarray | None = None, param: Any | None = None
@@ -134,7 +134,6 @@ class BaseImageItem(QwtPlotItem):
         if data is not None:
             self.set_data(data)
         self.param.update_item(self)
-        self.setIcon(get_icon("image.png"))
 
     # ---- Public API ----------------------------------------------------------
     def get_default_param(self) -> Any:
@@ -398,7 +397,8 @@ class BaseImageItem(QwtPlotItem):
         """
         title = self.title().text()
         z = self.get_data(x, y)
-        return f"{title}:<br>x = {int(x):d}<br>y = {int(y):d}<br>z = {z:g}"
+        zstr = "--" if z is np.ma.masked else f"{z:g}"
+        return f"{title}:<br>x = {int(x):d}<br>y = {int(y):d}<br>z = {zstr}"
 
     def set_background_color(self, qcolor: QColor | str) -> None:
         """Set background color
@@ -776,6 +776,22 @@ class BaseImageItem(QwtPlotItem):
         """
         return self.data is None or self.data.size == 0
 
+    def get_icon_name(self) -> str:
+        """Return the icon name
+
+        Returns:
+            Icon name
+        """
+        return self._icon_name
+
+    def set_icon_name(self, icon_name: str) -> None:
+        """Set the icon name
+
+        Args:
+            icon_name: Icon name
+        """
+        self._icon_name = icon_name
+
     def set_selectable(self, state: bool) -> None:
         """Set item selectable state
 
