@@ -6,13 +6,13 @@ import sys
 from typing import TYPE_CHECKING
 
 import numpy as np
-from guidata.configtools import get_icon
 from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 from qtpy import QtCore as QC
 
 from plotpy import io
 from plotpy.config import _
+from plotpy.constants import X_BOTTOM, Y_LEFT
 from plotpy.coords import axes_to_canvas
 from plotpy.interfaces import (
     IBaseImageItem,
@@ -205,6 +205,7 @@ class Histogram2DItem(BaseImageItem):
     """
 
     __implements__ = (IBasePlotItem, IBaseImageItem, IHistDataSource, IVoiImageItemType)
+    _icon_name = "histogram2d.png"
 
     def __init__(
         self,
@@ -233,7 +234,6 @@ class Histogram2DItem(BaseImageItem):
 
         self.set_lut_range([0, 10.0])
         self.set_data(X, Y, Z)
-        self.setIcon(get_icon("histogram2d.png"))
 
     # ---- BaseImageItem API ---------------------------------------------------
     def get_default_param(self) -> Histogram2DParam:
@@ -538,7 +538,7 @@ def get_plot_qrect(plot: qwt.plot.QwtPlot, p0: QPointF, p1: QPointF) -> QRectF:
     Returns:
         Plot rectangle
     """
-    ax, ay = plot.X_BOTTOM, plot.Y_LEFT
+    ax, ay = X_BOTTOM, Y_LEFT
     p0x, p0y = plot.invTransform(ax, p0.x()), plot.invTransform(ay, p0.y())
     p1x, p1y = plot.invTransform(ax, p1.x() + 1), plot.invTransform(ay, p1.y() + 1)
     return QC.QRectF(p0x, p0y, p1x - p0x, p1y - p0y)
