@@ -113,6 +113,7 @@ class ImageStatsRectangle(AnnotatedRectangle):
     """
 
     shape: PolygonShape
+    _icon_name = "imagestats.png"
 
     def __init__(
         self,
@@ -127,7 +128,6 @@ class ImageStatsRectangle(AnnotatedRectangle):
         """_summary_"""
         super().__init__(x1, y1, x2, y2, annotationparam)
         self.image_item: BaseImageItem | None = None
-        self.setIcon(get_icon("imagestats.png"))
         self.stats_func = stats_func
         self.replace_stats = replace
 
@@ -642,18 +642,17 @@ class ColormapTool(CommandTool):
             self.update_plot(self._active_colormap.name)
             self.update_status(plot)
 
-    def update_plot(self, cmap: str) -> None:
+    def update_plot(self, cmap_name: str) -> None:
         """Update the plot with the given colormap.
 
         Args:
-            cmap: Colormap name
+            cmap_name: Colormap name
         """
         plot: BasePlot = self.get_active_plot()
         items = get_selected_images(plot, IColormapImageItemType)
         for item in items:
-            param: BaseImageParam = item.param
-            param.colormap = cmap
-            param.update_item(item)
+            cmap = item.get_color_map()
+            item.set_color_map(cmap_name, cmap.invert)
             plot.SIG_ITEM_PARAMETERS_CHANGED.emit(item)
         plot.invalidate()
 
@@ -705,10 +704,9 @@ class ReverseColormapTool(ToggleTool):
         if self._active_colormap is not None and plot is not None:
             items = get_selected_images(plot, IColormapImageItemType)
             for item in items:
-                param: BaseImageParam = item.param
-                param.invert_colormap = checked
-                param.update_item(item)
-                plot.SIG_ITEM_PARAMETERS_CHANGED.emit(item)
+                cmap = item.get_color_map()
+                item.set_color_map(cmap.name, invert=checked)
+            plot.SIG_ITEM_PARAMETERS_CHANGED.emit(item)
             plot.invalidate()
             self.update_status(plot)
 
@@ -1093,9 +1091,9 @@ class LockTrImageTool(ToggleTool):
             for item in itemlist:
                 item.set_locked(checked)
                 if item.is_locked():
-                    item.setIcon(get_icon("trimage_lock.png"))
+                    item.set_icon_name("trimage_lock.png")
                 else:
-                    item.setIcon(get_icon("image.png"))
+                    item.set_icon_name("image.png")
                 plot.SIG_ITEM_PARAMETERS_CHANGED.emit(item)
             plot.SIG_ITEMS_CHANGED.emit(plot)
 
